/* ============================================================ */
/*   Nom de la base   :  MCD_HOTEL                              */
/*   Nom de SGBD      :  Sybase SQL Server 10                   */
/*   Date de cration :  16/01/2001  22:38                      */
/*   Copyright        :  Frdric BROUARD		        */            
/* ============================================================ */

/* ============================================================ */
/*   Table : T_CHAMBRE                                          */
/* ============================================================ */
create table T_CHAMBRE
(
    CHB_ID               int                    not null,
    CHB_NUMERO           smallint               not null,
    CHB_ETAGE            char(3)                null    ,
    CHB_BAIN             bit                    default 0 not null,
    CHB_DOUCHE           bit                    default 1 not null,
    CHB_WC               bit                    default 1 not null,
    CHB_COUCHAGE         smallint               not null,
    CHB_POSTE_TEL        char(3)                null    ,
    constraint PK_T_CHAMBRE primary key (CHB_ID)
)
go

/* ============================================================ */
/*   Table : T_TARIF                                            */
/* ============================================================ */
create table T_TARIF
(
    TRF_DATE_DEBUT       datetime               not null,
    TRF_TAUX_TAXES       numeric                not null,
    TRF_PETIT_DEJEUNE    money                  not null,
    constraint PK_T_TARIF primary key (TRF_DATE_DEBUT)
)
go

/* ============================================================ */
/*   Table : T_PLANNING                                         */
/* ============================================================ */
create table T_PLANNING
(
    PLN_JOUR             datetime               not null,
    constraint PK_T_PLANNING primary key (PLN_JOUR)
)
go

/* ============================================================ */
/*   Table : T_TITRE                                            */
/* ============================================================ */
create table T_TITRE
(
    TIT_CODE             char(8)                not null,
    TIT_LIBELLE          varchar(32)            not null,
    constraint PK_T_TITRE primary key (TIT_CODE)
)
go

/* ============================================================ */
/*   Table : T_TYPE                                             */
/* ============================================================ */
create table T_TYPE
(
    TYP_CODE             char(8)                not null,
    TYP_LIBELLE          varchar(32)            not null,
    constraint PK_T_TYPE primary key (TYP_CODE)
)
go

/* ============================================================ */
/*   Table : T_MODE_PAIEMENT                                    */
/* ============================================================ */
create table T_MODE_PAIEMENT
(
    PMT_CODE             char(8)                not null,
    PMT_LIBELLE          varchar(64)            not null,
    constraint PK_T_MODE_PAIEMENT primary key (PMT_CODE)
)
go

/* ============================================================ */
/*   Table : T_CLIENT                                           */
/* ============================================================ */
create table T_CLIENT
(
    CLI_ID               int                    not null,
    TIT_CODE             char(8)                null    ,
    CLI_NOM              char(32)               not null,
    CLI_PRENOM           varchar(25)            null    ,
    CLI_ENSEIGNE         varchar(100)           null    ,
    constraint PK_T_CLIENT primary key (CLI_ID)
)
go

/* ============================================================ */
/*   Index : L_CLI_TIT_FK                                       */
/* ============================================================ */
create index L_CLI_TIT_FK on T_CLIENT (TIT_CODE)
go

/* ============================================================ */
/*   Table : T_FACTURE                                          */
/* ============================================================ */
create table T_FACTURE
(
    FAC_ID               int                    not null,
    CLI_ID               int                    not null,
    PMT_CODE             char(8)                null    ,
    FAC_DATE             datetime               not null,
    FAC_PMT_DATE         datetime               null    ,
    constraint PK_T_FACTURE primary key (FAC_ID)
)
go

/* ============================================================ */
/*   Index : L_FAC_CLI_FK                                       */
/* ============================================================ */
create index L_FAC_CLI_FK on T_FACTURE (CLI_ID)
go

/* ============================================================ */
/*   Index : TJ_FAC_PMT_FK                                      */
/* ============================================================ */
create index TJ_FAC_PMT_FK on T_FACTURE (PMT_CODE)
go

/* ============================================================ */
/*   Table : T_ADRESSE                                          */
/* ============================================================ */
create table T_ADRESSE
(
    ADR_ID               int                    not null,
    CLI_ID               int                    not null,
    ADR_LIGNE1           varchar(32)            not null,
    ADR_LIGNE2           varchar(32)            null    ,
    ADR_LIGNE3           varchar(32)            null    ,
    ADR_LIGNE4           varchar(32)            null    ,
    ADR_CP               char(5)                not null,
    ADR_VILLE            char(32)               not null,
    constraint PK_T_ADRESSE primary key (ADR_ID)
)
go

/* ============================================================ */
/*   Index : L_ADR_CLI_FK                                       */
/* ============================================================ */
create index L_ADR_CLI_FK on T_ADRESSE (CLI_ID)
go

/* ============================================================ */
/*   Table : T_TELEPHONE                                        */
/* ============================================================ */
create table T_TELEPHONE
(
    TEL_ID               int                    not null,
    CLI_ID               int                    not null,
    TYP_CODE             char(8)                not null,
    TEL_NUMERO           char(20)               not null,
    TEL_LOCALISATION     varchar(64)            null    ,
    constraint PK_T_TELEPHONE primary key (TEL_ID)
)
go

/* ============================================================ */
/*   Index : L_TEL_CLI_FK                                       */
/* ============================================================ */
create index L_TEL_CLI_FK on T_TELEPHONE (CLI_ID)
go

/* ============================================================ */
/*   Index : L_TEL_TYP_FK                                       */
/* ============================================================ */
create index L_TEL_TYP_FK on T_TELEPHONE (TYP_CODE)
go

/* ============================================================ */
/*   Table : T_EMAIL                                            */
/* ============================================================ */
create table T_EMAIL
(
    EML_ID               int                    not null,
    CLI_ID               int                    not null,
    EML_ADRESSE          varchar(100)           not null,
    EML_LOCALISATION     varchar(64)            null    ,
    constraint PK_T_EMAIL primary key (EML_ID)
)
go

/* ============================================================ */
/*   Index : L_EML_CLI_FK                                       */
/* ============================================================ */
create index L_EML_CLI_FK on T_EMAIL (CLI_ID)
go

/* ============================================================ */
/*   Table : T_LIGNE_FACTURE                                    */
/* ============================================================ */
create table T_LIGNE_FACTURE
(
    LIF_ID               int                    not null,
    FAC_ID               int                    not null,
    LIF_QTE              numeric                not null,
    LIF_REMISE_POURCENT  numeric                null    ,
    LIF_REMISE_MONTANT   money                  null    ,
    LIF_MONTANT          money                  not null,
    LIF_TAUX_TVA         numeric                not null,
    constraint PK_T_LIGNE_FACTURE primary key (LIF_ID)
)
go

/* ============================================================ */
/*   Index : L_LIF_FAC_FK                                       */
/* ============================================================ */
create index L_LIF_FAC_FK on T_LIGNE_FACTURE (FAC_ID)
go

/* ============================================================ */
/*   Table : TJ_TRF_CHB                                         */
/* ============================================================ */
create table TJ_TRF_CHB
(
    CHB_ID               int                    not null,
    TRF_DATE_DEBUT       datetime               not null,
    TRF_CHB_PRIX         money                  not null,
    constraint PK_TJ_TRF_CHB primary key (CHB_ID, TRF_DATE_DEBUT)
)
go

/* ============================================================ */
/*   Index : L_CHB_TRF_FK                                       */
/* ============================================================ */
create index L_CHB_TRF_FK on TJ_TRF_CHB (CHB_ID)
go

/* ============================================================ */
/*   Index : L_TRF_CHB_FK                                       */
/* ============================================================ */
create index L_TRF_CHB_FK on TJ_TRF_CHB (TRF_DATE_DEBUT)
go

/* ============================================================ */
/*   Table : TJ_CHB_PLN_CLI                                     */
/* ============================================================ */
create table TJ_CHB_PLN_CLI
(
    CHB_ID               int                    not null,
    PLN_JOUR             datetime               not null,
    CLI_ID               int                    not null,
    CHB_PLN_CLI_NB_PERS  smallint               not null,
    CHB_PLN_CLI_RESERVE  bit                    default 0 not null,
    CHB_PLN_CLI_OCCUPE   bit                    default 1 not null,
    constraint PK_TJ_CHB_PLN_CLI primary key (CHB_ID, PLN_JOUR)
)
go

/* ============================================================ */
/*   Index : L_CHB_PLN_CLI_FK                                   */
/* ============================================================ */
create index L_CHB_PLN_CLI_FK on TJ_CHB_PLN_CLI (CHB_ID)
go

/* ============================================================ */
/*   Index : L_PLN_CHB_CLI_FK                                   */
/* ============================================================ */
create index L_PLN_CHB_CLI_FK on TJ_CHB_PLN_CLI (PLN_JOUR)
go

/* ============================================================ */
/*   Index : L_CLI_CHB_PLN_FK                                   */
/* ============================================================ */
create index L_CLI_CHB_PLN_FK on TJ_CHB_PLN_CLI (CLI_ID)
go

alter table T_CLIENT
    add constraint FK_T_CLIENT_L_CLI_TIT_T_TITRE foreign key  (TIT_CODE)
       references T_TITRE (TIT_CODE)
go

alter table T_FACTURE
    add constraint FK_T_FACTUR_L_FAC_CLI_T_CLIENT foreign key  (CLI_ID)
       references T_CLIENT (CLI_ID)
go

alter table T_FACTURE
    add constraint FK_T_FACTUR_TJ_FAC_PM_T_MODE_P foreign key  (PMT_CODE)
       references T_MODE_PAIEMENT (PMT_CODE)
go

alter table T_ADRESSE
    add constraint FK_T_ADRESS_L_ADR_CLI_T_CLIENT foreign key  (CLI_ID)
       references T_CLIENT (CLI_ID)
go

alter table T_TELEPHONE
    add constraint FK_T_TELEPH_L_TEL_CLI_T_CLIENT foreign key  (CLI_ID)
       references T_CLIENT (CLI_ID)
go

alter table T_TELEPHONE
    add constraint FK_T_TELEPH_L_TEL_TYP_T_TYPE foreign key  (TYP_CODE)
       references T_TYPE (TYP_CODE)
go

alter table T_EMAIL
    add constraint FK_T_EMAIL_L_EML_CLI_T_CLIENT foreign key  (CLI_ID)
       references T_CLIENT (CLI_ID)
go

alter table T_LIGNE_FACTURE
    add constraint FK_T_LIGNE__L_LIF_FAC_T_FACTUR foreign key  (FAC_ID)
       references T_FACTURE (FAC_ID)
go

alter table TJ_TRF_CHB
    add constraint FK_TJ_TRF_C_L_CHB_TRF_T_CHAMBR foreign key  (CHB_ID)
       references T_CHAMBRE (CHB_ID)
go

alter table TJ_TRF_CHB
    add constraint FK_TJ_TRF_C_L_TRF_CHB_T_TARIF foreign key  (TRF_DATE_DEBUT)
       references T_TARIF (TRF_DATE_DEBUT)
go

alter table TJ_CHB_PLN_CLI
    add constraint FK_TJ_CHB_P_L_CHB_PLN_T_CHAMBR foreign key  (CHB_ID)
       references T_CHAMBRE (CHB_ID)
go

alter table TJ_CHB_PLN_CLI
    add constraint FK_TJ_CHB_P_L_PLN_CHB_T_PLANNI foreign key  (PLN_JOUR)
       references T_PLANNING (PLN_JOUR)
go

alter table TJ_CHB_PLN_CLI
    add constraint FK_TJ_CHB_P_L_CLI_CHB_T_CLIENT foreign key  (CLI_ID)
       references T_CLIENT (CLI_ID)
go

